==> myfaces-tobago-1.5.13-source-release.zip: tobago-1.5.13/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/PageDeclarationLanguageBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import javax.faces.context.FacesContext;

public class PageDeclarationLanguageBean {

  private PageDeclarationLanguage language = PageDeclarationLanguage.FACELETS;

  public PageDeclarationLanguage getLanguage() {
    return language;
  }

  public void setLanguage(PageDeclarationLanguage language) {
    this.language = language;
  }

  public String asFacelets() {
    language = PageDeclarationLanguage.FACELETS;
    return FacesContext.getCurrentInstance().getViewRoot().getViewId();

  }

  public String asJspx() {
    language = PageDeclarationLanguage.JSPX;
    return FacesContext.getCurrentInstance().getViewRoot().getViewId();
  }

  public boolean isFacelets() {
    return language == PageDeclarationLanguage.FACELETS;
  }

  public boolean isJspx() {
    return language == PageDeclarationLanguage.JSPX;
  }
}

==> myfaces-tobago-2.5.3-source-release.zip: tobago-2.5.3/tobago-example/tobago-example-demo/src/main/java/org/apache/myfaces/tobago/example/demo/PageDeclarationLanguageBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.example.demo;

import javax.faces.context.FacesContext;

public class PageDeclarationLanguageBean {

  private PageDeclarationLanguage language = PageDeclarationLanguage.FACELETS;

  public PageDeclarationLanguage getLanguage() {
    return language;
  }

  public void setLanguage(final PageDeclarationLanguage language) {
    this.language = language;
  }

  public String asFacelets() {
    language = PageDeclarationLanguage.FACELETS;
    return FacesContext.getCurrentInstance().getViewRoot().getViewId();

  }

  public String asJspx() {
    language = PageDeclarationLanguage.JSPX;
    return FacesContext.getCurrentInstance().getViewRoot().getViewId();
  }

  public boolean isFacelets() {
    return language == PageDeclarationLanguage.FACELETS;
  }

  public boolean isJspx() {
    return language == PageDeclarationLanguage.JSPX;
  }
}
